Documentation
¶
Index ¶
- func CredentialKey(host string) string
- func DeleteHostCredentials(host string) error
- func GetValidToken(ctx context.Context, host string) (string, error)
- func Login(ctx context.Context, host string) error
- func Logout(host string) error
- func OpenBrowser(url string) error
- func SaveConfig(cfg *Config) error
- func SaveCredentials(creds Credentials) error
- func SaveHostCredentials(host string, hostCreds HostCredentials) error
- type Config
- type Credentials
- type HostCredentials
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CredentialKey ¶ added in v0.13.0
CredentialKey normalizes a host to its bare form (without "api." prefix) so that credentials are stored and looked up consistently regardless of whether the caller passes "acme.nullify.ai" or "api.acme.nullify.ai".
func DeleteHostCredentials ¶
func OpenBrowser ¶ added in v0.13.0
OpenBrowser opens the given URL in the user's default browser.
func SaveConfig ¶
func SaveCredentials ¶
func SaveCredentials(creds Credentials) error
func SaveHostCredentials ¶
func SaveHostCredentials(host string, hostCreds HostCredentials) error
Types ¶
type Credentials ¶
type Credentials map[string]HostCredentials
func LoadCredentials ¶
func LoadCredentials() (Credentials, error)
Click to show internal directories.
Click to hide internal directories.