Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func HandleError ¶
HandleError reads an HTTP error response and returns a structured *APIError.
Types ¶
type APIError ¶
APIError represents a structured error response from the Nullify API.
func (*APIError) IsNotFound ¶
IsNotFound returns true if the error is a 404 Not Found.
func (*APIError) IsUnauthorized ¶
IsUnauthorized returns true if the error is a 401 Unauthorized.
Click to show internal directories.
Click to hide internal directories.