Documentation
¶
Index ¶
- Constants
- func GetGitHubID(ctx context.Context, githubOwner string) (string, error)
- func HandleError(resp *http.Response) error
- func Int(value int) *int
- func NewRetryTransport(transport http.RoundTripper) http.RoundTripper
- func String(value string) *string
- type APIError
- type DASTCreateExternalScanInput
- type DASTCreateExternalScanOutput
- type DASTStartCloudScanInput
- type DASTStartCloudScanOutput
- type DASTUpdateExternalScanInput
- type HTTPClient
- type NullifyClient
- func (c *NullifyClient) DASTCreateExternalScan(ctx context.Context, githubOwner string, input *DASTCreateExternalScanInput) (*DASTCreateExternalScanOutput, error)
- func (c *NullifyClient) DASTStartCloudScan(ctx context.Context, githubOwner string, input *DASTStartCloudScanInput) (*DASTStartCloudScanOutput, error)
- func (c *NullifyClient) DASTUpdateExternalScan(ctx context.Context, githubOwner string, githubRepository string, ...) error
- type TokenProvider
Constants ¶
const (
StatusCompleted = "completed"
)
Variables ¶
This section is empty.
Functions ¶
func GetGitHubID ¶ added in v0.9.15
func HandleError ¶
HandleError reads an HTTP error response and returns a structured *APIError.
func NewRetryTransport ¶ added in v0.13.0
func NewRetryTransport(transport http.RoundTripper) http.RoundTripper
NewRetryTransport wraps the given transport with retry logic for 429 and 5xx errors.
Types ¶
type APIError ¶ added in v0.12.0
APIError is an alias for apierror.APIError for backwards compatibility.
type DASTCreateExternalScanInput ¶ added in v0.7.0
type DASTCreateExternalScanOutput ¶ added in v0.7.0
type DASTCreateExternalScanOutput struct {
ScanID string `json:"scanId"`
}
type DASTStartCloudScanInput ¶ added in v0.4.0
type DASTStartCloudScanInput struct {
AppName string `json:"appName"`
TargetHost string `json:"targetHost"`
OpenAPISpec map[string]any `json:"openAPISpec"`
AuthConfig models.AuthConfig `json:"authConfig"`
models.RequestProvider
models.RequestDashboardTarget
}
type DASTStartCloudScanOutput ¶ added in v0.7.0
type DASTStartCloudScanOutput struct {
ScanID string `json:"scanId"`
}
type DASTUpdateExternalScanInput ¶ added in v0.7.0
type DASTUpdateExternalScanInput struct {
Progress *int `json:"progress"`
Status *string `json:"status"`
Findings []models.DASTFinding `json:"findings"`
*models.RequestDashboardTarget
}
type HTTPClient ¶ added in v0.12.0
HTTPClient defines the interface for making HTTP requests.
type NullifyClient ¶ added in v0.4.0
type NullifyClient struct {
Host string
BaseURL string
Token string
HttpClient HTTPClient
}
NullifyClient wraps an HTTP client configured for the Nullify API.
func NewNullifyClient ¶ added in v0.4.0
func NewNullifyClient(nullifyHost string, token string) *NullifyClient
NewNullifyClient creates a client for the given host with bearer token auth.
func NewRefreshingNullifyClient ¶ added in v0.13.0
func NewRefreshingNullifyClient(nullifyHost string, tokenProvider TokenProvider) (*NullifyClient, error)
NewRefreshingNullifyClient creates a NullifyClient that automatically refreshes its auth token, suitable for long-running processes like MCP servers.
func (*NullifyClient) DASTCreateExternalScan ¶ added in v0.7.0
func (c *NullifyClient) DASTCreateExternalScan( ctx context.Context, githubOwner string, input *DASTCreateExternalScanInput, ) (*DASTCreateExternalScanOutput, error)
func (*NullifyClient) DASTStartCloudScan ¶ added in v0.4.0
func (c *NullifyClient) DASTStartCloudScan( ctx context.Context, githubOwner string, input *DASTStartCloudScanInput, ) (*DASTStartCloudScanOutput, error)
func (*NullifyClient) DASTUpdateExternalScan ¶ added in v0.7.0
func (c *NullifyClient) DASTUpdateExternalScan( ctx context.Context, githubOwner string, githubRepository string, scanID string, input *DASTUpdateExternalScanInput, ) error
type TokenProvider ¶ added in v0.13.0
TokenProvider is a function that returns a valid token.
Click to show internal directories.
Click to hide internal directories.