Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Version string
Version is set at build time via ldflags.
Functions ¶
func Close ¶
Close flushes the logger, ignoring the sync error that is expected on stderr-based loggers (see https://github.com/uber-go/zap/issues/880).
func ConfigureDevelopmentLogger ¶
ConfigureDevelopmentLogger creates a zap development logger at the given level, stores it in the returned context, and returns the context. Logs are written to stderr so they don't corrupt piped stdout output.
Types ¶
Click to show internal directories.
Click to hide internal directories.